@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("3.4.") or
-    raise "ruby lib version (3.4.3) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (3.4.4) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.4.0/aarch64-linux")
@@ -21,8 +21,8 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
   CONFIG["MINOR"] = "4"
-  CONFIG["TEENY"] = "3"
-  CONFIG["PATCHLEVEL"] = "32"
+  CONFIG["TEENY"] = "4"
+  CONFIG["PATCHLEVEL"] = "34"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr")
@@ -143,8 +143,6 @@ module RbConfig
   CONFIG["ARCH_FLAG"] = ""
   CONFIG["DLDFLAGS"] = "-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now -Wl,--compress-debug-sections=zlib"
   CONFIG["ALLOCA"] = ""
-  CONFIG["EGREP"] = "/usr/bin/grep -E"
-  CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["dsymutil"] = ""
   CONFIG["codesign"] = ""
   CONFIG["cleanlibs"] = ""
